%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  units were defined as follows:
%       time   :  minutes; 
%       age    :  year;
%       weight :  kilogram;
%       volume :  litre;
%       conc   :  umol/litre;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
    clear;
    disp('restart');        
%
%   %--------------------------------------------%
%    Loading PBPK parameters and experimetal data
%   %--------------------------------------------%
%       
    % setup default PBPK parameters.
    [organ, drug, enzyme, protein, const] = defaultParams(); 
    assignIndex();     %Assign index to each name                                                        
%
%   %---------------------%
%    Solve ODE
%   %---------------------%   
%
    numOrgan = organ(1).number;            
    co = zeros(drug(1).number*numOrgan,1); 
 
    tSpan = [0 5760]; % seconds 
    warning off all     
    [tStore,cStore] = ode23s(@ODESetup,tSpan,co,[],organ,drug,enzyme,protein,const);  
    co = cStore(end,:);   % update initial co.                
%    
%   %--------------------------------%           
%    Plot simulated data. 
%   %--------------------------------%     
%    
    % r-methadone
    Xr = drug(r_methadone).expData(:,1); % in minutes
    Yr = drug(r_methadone).expData(:,2); % in umol/liters    

    % s-methadone
    Xs = drug(s_methadone).expData(:,1); % in minutes. 
    Ys = drug(s_methadone).expData(:,2); % um/l.
    
    figure1 = figure;
    axes1 = axes('FontSize',18,'Parent',figure1,'box','on');  
    hold(axes1,'all'); 
    
    for isolute = 1:drug(1).number  % for different drugs
        t = tStore + drug(isolute).iphase(1).tSpan(1); 
        Y = cStore(:, (isolute-1)*organ(1).number+artery);
        scatter(Xr./60,Yr, 'Marker','square', 'MarkerEdgeColor','k','MarkerFaceColor','k'); hold on; %'filled');               
        scatter(Xs./60,Ys, 'Marker','o',  'MarkerEdgeColor','k','MarkerFaceColor','k');  %'filled');               
        box(axes1,'on');
        hold(axes1,'all');                     

        if isolute == r_methadone
           plot(t./60, Y,'LineWidth',1.5,'Color', 'k','LineStyle','-'); hold on;
        elseif isolute == s_methadone
           plot(t./60, Y,'LineWidth',1.5,'Color', 'k','LineStyle','--'); hold on;
        end
    end
        
    xlabel(axes1, 'Time (hours)');
    ylabel(axes1, 'Plasma concentration (\mum/l)');    
    legend2 = legend(axes1,{ 'exp R-methadone',...
                             'exp S-methadone',}, 'FontSize',12,1);  
    axis([-1 96 1e-3 0.15]);             
    print -depsc singlePLot.eps
        
    return
    
    
    
